@@ -52,11 +52,16 @@ const QString DisplayManagerService("org.freedesktop.DisplayManager");
 
 const QString AutoLoginVisable = "auto-login-visable";
 const QString NoPasswordVisable = "nopasswd-login-visable";
+const QString Sysadm_u = "sysadm_u";
+const QString Secadm_u = "secadm_u";
+const QString Audadm_u = "audadm_u";
+const QString Auditadm_u = "auditadm_u";
 
 AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     : QObject(parent)
     , m_accountsInter(new Accounts(AccountsService, "/com/deepin/daemon/Accounts", QDBusConnection::systemBus(), this))
     , m_syncHelperInter(new QDBusInterface("com.deepin.sync.Helper", "/com/deepin/sync/Helper", "com.deepin.sync.Helper", QDBusConnection::systemBus(), this))
+    , m_userQInter(new QDBusInterface("com.deepin.daemon.Accounts", QString("/com/deepin/daemon/Accounts/User%1").arg(getuid()), "com.deepin.daemon.Accounts.User", QDBusConnection::systemBus(), this))
     , m_fingerPrint(new Fingerprint(FingerPrintService, "/com/deepin/daemon/Authenticate/Fingerprint", QDBusConnection::systemBus(), this))
 #ifdef DCC_ENABLE_ADDOMAIN
     , m_notifyInter(new Notifications("org.freedesktop.Notifications", "/org/freedesktop/Notifications", QDBusConnection::sessionBus(), this))
@@ -64,10 +69,13 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     , m_dmInter(new DisplayManager(DisplayManagerService, "/org/freedesktop/DisplayManager", QDBusConnection::systemBus(), this))
     , m_userModel(userList)
 {
+    qRegisterMetaType<SecurityQuestions>("SecurityQuestions");
+    qDBusRegisterMetaType<SecurityQuestions>();
     struct passwd *pws;
     pws = getpwuid(getuid());
     m_currentUserName = QString(pws->pw_name);
     m_userModel->setCurrentUserName(m_currentUserName);
+    m_userModel->setIsSecurityHighLever(hasOpenSecurity());
 
     connect(m_accountsInter, &Accounts::UserListChanged, this, &AccountsWorker::onUserListChanged, Qt::QueuedConnection);
     connect(m_accountsInter, &Accounts::UserAdded, this, &AccountsWorker::addUser, Qt::QueuedConnection);
@@ -96,7 +104,7 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
 
         m_userModel->setAutoLoginVisable(gsetting->get(AutoLoginVisable).toBool());
         m_userModel->setNoPassWordLoginVisable(gsetting->get(NoPasswordVisable).toBool());
-        connect(gsetting, &QGSettings::changed, m_userModel, [=](const QString &key) {
+        connect(gsetting, &QGSettings::changed, m_userModel, [ = ](const QString &key) {
             if (key == "autoLoginVisable") {
                 m_userModel->setAutoLoginVisable(gsetting->get(AutoLoginVisable).toBool());
             } else if (key == "nopasswdLoginVisable") {
@@ -202,6 +210,31 @@ void AccountsWorker::startResetPasswordExec(User *user)
     Q_EMIT user->startResetPasswordReplied(reply.error().message());
 }
 
+void AccountsWorker::asyncSecurityQuestionsCheck(User *user)
+{
+    QFutureWatcher<QList<int>> *watcher = new QFutureWatcher<QList<int>>(this);
+    connect(watcher, &QFutureWatcher<QList<int>>::finished, [user, watcher] {
+        QList<int> result = watcher->result();
+        if (result.size() != SECURITY_QUESTIONS_ERROR_COUNT)
+            Q_EMIT user->startSecurityQuestionsCheckReplied(result);
+        watcher->deleteLater();
+    });
+    QFuture<QList<int>> future = QtConcurrent::run(this, &AccountsWorker::securityQuestionsCheck);
+    watcher->setFuture(future);
+}
+
+QList<int> AccountsWorker::securityQuestionsCheck()
+{
+    QDBusReply<QList<int>> reply = m_userQInter->call("GetSecretQuestions");
+    if (!reply.error().message().isEmpty()) {
+        qWarning() << reply.error().message();
+    }
+    if (reply.isValid()) {
+        return reply.value();
+    }
+    return {-1};
+}
+
 void AccountsWorker::setPasswordHint(User *user, const QString &passwordHint)
 {
     AccountsUser *userInter = m_userInters.value(user);
@@ -210,6 +243,64 @@ void AccountsWorker::setPasswordHint(User *user, const QString &passwordHint)
     userInter->SetPasswordHint(passwordHint);
 }
 
+void AccountsWorker::setSecurityQuestions(User *user, const QMap<int, QByteArray> &securityQuestions)
+{
+    QDBusReply<void> reply =  m_userQInter->call("SetSecretQuestions", QVariant::fromValue(securityQuestions));
+    if (reply.isValid()) {
+        Q_EMIT user->setSecurityQuestionsReplied(reply.error().message());
+    }
+    if (!reply.error().message().isEmpty()) {
+        Q_EMIT user->setSecurityQuestionsReplied(reply.error().message() + "error");
+    }
+}
+
+bool AccountsWorker::hasOpenSecurity()
+{
+    QDBusInterface securityEnhance("com.deepin.daemon.SecurityEnhance",
+                            "/com/deepin/daemon/SecurityEnhance",
+                            "com.deepin.daemon.SecurityEnhance",
+                            QDBusConnection::systemBus());
+    QDBusMessage reply = securityEnhance.call("Status");
+    qDebug() << reply.errorMessage();
+    QList<QVariant> outArgs = reply.arguments();
+    if (outArgs.count() > 0) {
+        QString value  = outArgs.at(0).toString();
+        if (value == "open") {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+SecurityLever AccountsWorker::getSecUserLeverbyname(QString userName)
+{
+    QDBusInterface securityEnhance("com.deepin.daemon.SecurityEnhance",
+                            "/com/deepin/daemon/SecurityEnhance",
+                            "com.deepin.daemon.SecurityEnhance",
+                            QDBusConnection::systemBus());
+
+    QList<QVariant> currentUserSeName = securityEnhance.call("GetSEUserByName", userName).arguments();
+
+    if (currentUserSeName.count() > 0) {
+        QString value  = currentUserSeName.first().toString();
+        if (value == Sysadm_u) {
+            return SecurityLever::Sysadm;
+        }
+        if (value == Secadm_u) {
+            return SecurityLever::Secadm;
+        }
+        if (value == Audadm_u) {
+            return SecurityLever::Audadm;
+        }
+        if (value == Auditadm_u) {
+            return SecurityLever::Auditadm;
+        }
+    }
+
+    return SecurityLever::Standard;
+}
+
 void AccountsWorker::setGroups(User *user, const QStringList &usrGroups)
 {
     AccountsUser *userInter = m_userInters[user];
@@ -293,6 +384,7 @@ void AccountsWorker::setAvatar(User *user, const QString &iconPath)
 
 void AccountsWorker::setFullname(User *user, const QString &fullname)
 {
+    qDebug() << Q_FUNC_INFO << fullname;
     AccountsUser *ui = m_userInters[user];
     Q_ASSERT(ui);
 
@@ -302,6 +394,7 @@ void AccountsWorker::setFullname(User *user, const QString &fullname)
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
         if (!call.isError()) {
+            qDebug() << Q_FUNC_INFO << "accountFullNameChangeFinished";
             Q_EMIT accountFullNameChangeFinished();
         }
 
@@ -469,6 +562,7 @@ void AccountsWorker::addUser(const QString &userPath)
 
     connect(userInter, &AccountsUser::UserNameChanged, user, [=](const QString &name) {
         user->setName(name);
+        user->setSecurityLever(getSecUserLeverbyname(name));
         user->setOnline(m_onlineUsers.contains(name));
         user->setIsCurrentUser(name == m_currentUserName);
 #ifdef DCC_ENABLE_ADDOMAIN
@@ -798,3 +892,19 @@ BindCheckResult AccountsWorker::checkLocalBind(const QString &uosid, const QStri
     }
     return result;
 }
+
+void AccountsWorker::checkPwdLimitLevel()
+{
+    // 密码校验失败并且安全中心密码安全等级不为低，弹出跳转到安全中心的对话框，低、中、高等级分别对应的值为1、2、3
+    QDBusInterface interface(QStringLiteral("com.deepin.defender.daemonservice"),
+                             QStringLiteral("/com/deepin/defender/daemonservice"),
+                             QStringLiteral("com.deepin.defender.daemonservice"));
+    if (!interface.isValid()) {
+        return;
+    }
+    QDBusReply<int> level = interface.call("GetPwdLimitLevel");
+    if (level.error().type() == QDBusError::NoError && level != 1) {
+        QDBusReply<QString> errorTips = interface.call("GetPwdError");
+        Q_EMIT showSafeyPage(errorTips);
+    }
+}
