@@ -40,6 +40,7 @@ CharaMangerWorker::CharaMangerWorker(CharaMangerModel *model, QObject *parent)
     , m_charaMangerInter(new CharaManger(CharaMangerService, "/com/deepin/daemon/Authenticate/CharaManger",
                                   QDBusConnection::systemBus(), this))
     , m_stopTimer(new QTimer(this))
+    , m_fileDescriptor(nullptr)
     , m_dbusSenderID("")
     , m_currentInputCharaType(0)
 {
@@ -56,8 +57,22 @@ CharaMangerWorker::CharaMangerWorker(CharaMangerModel *model, QObject *parent)
     connect(m_charaMangerInter, &CharaManger::DriverInfoChanged, this, &CharaMangerWorker::predefineDriverInfo);
     connect(m_charaMangerInter, &CharaManger::DriverChanged, this, &CharaMangerWorker::refreshDriverInfo);
 
-    auto driverInfo = m_charaMangerInter->driverInfo();
-    predefineDriverInfo(driverInfo);
+    // 获取DeviceInfo属性
+    QDBusInterface charaManagerInter("com.deepin.daemon.Authenticate",
+                             "/com/deepin/daemon/Authenticate/CharaManger",
+                             "org.freedesktop.DBus.Properties",
+                             QDBusConnection::systemBus());
+    QDBusPendingCall call = charaManagerInter.asyncCall("Get", "com.deepin.daemon.Authenticate.CharaManger", "DriverInfo");
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, [this, call, watcher] {
+        if (!call.isError()) {
+            QDBusReply<QDBusVariant> reply = call.reply();
+            predefineDriverInfo(reply.value().variant().toString());
+        } else {
+            qWarning() << "Failed to get driver info: " << call.error().message();
+        }
+        watcher->deleteLater();
+    });
 
     // 录入时间超时 停止录入
     connect(m_stopTimer, &QTimer::timeout, [this] {
@@ -252,11 +267,16 @@ void CharaMangerWorker::entollStart(const QString &driverName, const int &charaT
         } else {
             m_stopTimer->start(1000 * INPUT_TIME);
 
-            if (charaType & FACE_CHARA)
+            if (charaType & FACE_CHARA) {
+                Q_EMIT requestMainWindowEnabled(true);
                 m_model->setInputFaceFD(m_fileDescriptor->value().fileDescriptor());
+            }
 
-            if (charaType & IRIS_CHARA)
+            if (charaType & IRIS_CHARA) {
+                Q_EMIT requestMainWindowEnabled(true);
                 m_model->setInputIrisFD(CharaMangerModel::AddInfoState::Processing);
+            }
+
         }
         Q_EMIT requestMainWindowEnabled(true);
         watcher->deleteLater();
