@@ -121,11 +121,14 @@ void DisplayWorker::active()
     m_model->setmaxBacklightBrightness(m_displayInter.maxBacklightBrightness());
     m_model->setAutoLightAdjustIsValid(m_powerInter->hasAmbientLightSensor());
 
-    //redshift 依赖X11，当前isXWindowPlatform返回不准确,所以先用环境变量判断
-    auto sessionType = qEnvironmentVariable("XDG_SESSION_TYPE");
-    const bool isRedshiftValid =
-        !sessionType.contains("wayland") && QProcess::execute("which", QStringList() << "redshift") == 0;
-
+    bool isRedshiftValid = true;
+    QDBusInterface displayInter("com.deepin.daemon.Display","/com/deepin/daemon/Display",
+            "com.deepin.daemon.Display", QDBusConnection::sessionBus());
+    QDBusReply<bool> reply = displayInter.call("SupportSetColorTemperature");
+    if (QDBusError::NoError == reply.error().type())
+        isRedshiftValid = reply.value();
+    else
+        qWarning() << "Call SupportSetColorTemperature method failed: " << reply.error().message();
     m_model->setRedshiftIsValid(isRedshiftValid);
     m_model->setMinimumBrightnessScale(m_dccSettings->get(GSETTINGS_MINIMUM_BRIGHTNESS).toDouble());
     m_model->setResolutionRefreshEnable(m_dccSettings->get(GSETTINGS_SHOW_MUTILSCREEN).toBool());
@@ -142,7 +145,7 @@ void DisplayWorker::saveChanges()
 
 void DisplayWorker::switchMode(const int mode, const QString &name)
 {
-    m_displayInter.SwitchMode(static_cast<uchar>(mode), name).waitForFinished();
+    m_displayInter.SwitchMode(static_cast<uchar>(mode), name);
 }
 
 void DisplayWorker::onMonitorListChanged(const QList<QDBusObjectPath> &mons)
