@@ -32,6 +32,8 @@
 #include <QJsonObject>
 #include <QJsonValue>
 #include <QThreadPool>
+#include <QGuiApplication>
+
 #include "shortcutitem.h"
 
 static const QStringList systemFilter = {"terminal",
@@ -183,6 +185,10 @@ void ShortcutModel::onParseInfo(const QString &info)
     } else {
         systemShortKeys = systemFilter;
     }
+
+    if(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
+        systemShortKeys.removeOne("wm-switcher");
+    }
 #ifdef DISABLE_SCREEN_RECORDING
     QStringList systemFilterServer = systemShortKeys;
     systemFilterServer.removeOne("deepin-screen-recorder");
@@ -342,6 +348,9 @@ void ShortcutModel::setSearchResult(const QString &searchResult)
     QJsonArray array = QJsonDocument::fromJson(searchResult.toStdString().c_str()).array();
     for (auto value : array) {
         QJsonObject obj  = value.toObject();
+        if ((obj["Id"].toString() == "wm-switcher") && (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive))) {
+            continue;
+        }
         int         type = obj["Type"].toInt();
         ShortcutInfo *info = new ShortcutInfo();
         info->type         = type;
