@@ -266,16 +266,8 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
-    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkFullname);
-
-    //失焦后就提示
-    connect(m_passwdEdit, &DLineEdit::editingFinished, this, [ = ] {
-        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_nameEdit->lineEdit()->text(),
-                                                                                          m_passwdEdit->lineEdit()->text());
-        if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-            m_passwdEdit->setAlert(true);
-            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
-        }
+    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, [ = ]{
+        checkFullname();
     });
 
     //失焦后就提示，只检查密码一致性
@@ -286,7 +278,6 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
-
     connect(m_passwdEdit, &DPasswordEdit::textEdited, this, [ = ] {
         if (m_passwdEdit->isAlert()) {
             m_passwdEdit->hideAlertMessage();
@@ -378,26 +369,30 @@ void CreateAccountPage::showEvent(QShowEvent *event)
 
 void CreateAccountPage::createUser()
 {
-    bool check = false;
+    bool checkResult = true;
     //校验输入的用户名和密码
     if (!checkName()) {
-        check = true;
+        checkResult = false;
     }
 
-    if (!checkFullname()) {
-        check = true;
+    if (!checkFullname(checkResult)) {
+        checkResult = false;
     }
 
-    if (!checkPassword(m_repeatpasswdEdit)) {
-        check = true;
+    bool needShowSafetyPage = false;
+    if (!checkPassword(m_repeatpasswdEdit, needShowSafetyPage, checkResult)) {
+        checkResult = false;
     }
 
-    if (!checkPassword(m_passwdEdit)) {
-        check = true;
+    if (!checkPassword(m_passwdEdit, needShowSafetyPage, checkResult)) {
+        checkResult = false;
     }
 
 
-    if (check) {
+    if (!checkResult) {
+        if (needShowSafetyPage) {
+            Q_EMIT requestCheckPwdLimitLevel();
+        }
         return;
     }
 
@@ -441,7 +436,7 @@ void CreateAccountPage::createUser()
 void CreateAccountPage::setCreationResult(CreationResult *result)
 {
     switch (result->type()) {
-    case CreationResult::NoError:      
+    case CreationResult::NoError:
         Q_EMIT requestBack(AccountsWidget::CreateUserSuccess);
         break;
     case CreationResult::UserNameError:
@@ -499,20 +494,18 @@ bool CreateAccountPage::checkName()
 
     if (!m_accountWorker->isUsernameValid(userName).argumentAt(0).toBool() && NAME_ALREADY == m_accountWorker->isUsernameValid(userName).argumentAt(2).toInt()) {
         m_nameEdit->setAlert(true);
-        m_nameEdit->showAlertMessage(tr("The name already exists"), m_nameEdit, 2000);
+        m_nameEdit->showAlertMessage(tr("The username has been used by other user accounts"), m_nameEdit, 2000);
         return false;
     }
 
-
-    /* 暂时先屏蔽用户名与用户全名的重复性检查 */
-    // QList<User *> userList = m_userModel->userList();
-    // for (User *user : userList) {
-    //     if (userName == user->fullname()) {
-    //         m_nameEdit->setAlert(true);
-    //         m_nameEdit->showAlertMessage(tr("The name already exists"), m_nameEdit, 2000);
-    //         return false;
-    //     }
-    // }
+     QList<User *> userList = m_userModel->userList();
+     for (User *user : userList) {
+         if (userName == user->fullname()) {
+             m_nameEdit->setAlert(true);
+             m_nameEdit->showAlertMessage(tr("The username has been used by other user accounts"), m_nameEdit, 2000);
+             return false;
+         }
+     }
 
     if (m_nameEdit->isAlert()) {
         m_nameEdit->setAlert(false);
@@ -522,13 +515,14 @@ bool CreateAccountPage::checkName()
     return true;
 }
 
-bool CreateAccountPage::checkFullname()
+bool CreateAccountPage::checkFullname(bool showTips)
 {
     QString userFullName = m_fullnameEdit->lineEdit()->text();
 
     if (userFullName.size() > 32) {
         m_fullnameEdit->setAlert(true);
-        m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
+        if(showTips)
+            m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
         return false;
     }
 
@@ -536,8 +530,11 @@ bool CreateAccountPage::checkFullname()
     //vaild == false && code ==6 是用户名已存在
     if (!m_accountWorker->isUsernameValid(userFullName).argumentAt(0).toBool() && ErrCodeSystemUsed == m_accountWorker->isUsernameValid(userFullName).argumentAt(2).toInt()) {
         m_fullnameEdit->setAlert(true);
-        m_fullnameEdit->showAlertMessage(tr("The name already exists"), m_fullnameEdit, 2000);
-        m_fullnameEdit->lineEdit()->selectAll();
+        if(showTips){
+            m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+            m_fullnameEdit->lineEdit()->selectAll();
+        }
+
         return false;
     }
 
@@ -547,8 +544,11 @@ bool CreateAccountPage::checkFullname()
         for (User *user : userList) {
             if (userFullName == user->fullname() || userFullName == user->name()) {
                 m_fullnameEdit->setAlert(true);
-                m_fullnameEdit->showAlertMessage(tr("The username already exists"), m_fullnameEdit, 2000);
-                m_fullnameEdit->lineEdit()->selectAll();
+                if(showTips){
+                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                    m_fullnameEdit->lineEdit()->selectAll();
+                }
+
                 return false;
             }
         }
@@ -556,8 +556,11 @@ bool CreateAccountPage::checkFullname()
         for (QString &group : groupList) {
             if (userFullName == group) {
                 m_fullnameEdit->setAlert(true);
-                m_fullnameEdit->showAlertMessage(tr("The name already exists"), m_fullnameEdit, 2000);
-                m_fullnameEdit->lineEdit()->selectAll();
+                if(showTips){
+                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                    m_fullnameEdit->lineEdit()->selectAll();
+                }
+
                 return false;
             }
         }
@@ -573,12 +576,13 @@ bool CreateAccountPage::checkFullname()
     return true;
 }
 
-bool CreateAccountPage::checkPassword(DPasswordEdit *edit)
+bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage, bool showTips)
 {
     if (edit == m_repeatpasswdEdit) {
         if (m_passwdEdit->lineEdit()->text() != m_repeatpasswdEdit->lineEdit()->text()) {
             m_repeatpasswdEdit->setAlert(true);
-            m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
+            if(showTips)
+                m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
             return false;
         }
     }
@@ -588,40 +592,14 @@ bool CreateAccountPage::checkPassword(DPasswordEdit *edit)
 
     if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
         m_passwdEdit->setAlert(true);
-        m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
+        if(showTips)
+            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
 
         // 企业版控制中心用户创建屏蔽安全中心登录安全的接口需求
         if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise) || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC))
             return false;
 
-        QDBusInterface interface(QStringLiteral("com.deepin.defender.daemonservice"),
-                                                QStringLiteral("/com/deepin/defender/daemonservice"),
-                                                QStringLiteral("com.deepin.defender.daemonservice"));
-        if (!interface.isValid()) {
-            return false;
-        }
-
-        QDBusReply<int> level = interface.call("GetPwdLimitLevel");
-        if (level != 1) {
-            QDBusReply<QString> errorTips = interface.call("GetPwdError");
-            DDialog dlg("", errorTips, this);
-            dlg.setIcon(QIcon::fromTheme("preferences-system"));
-            dlg.addButton(tr("Go to Settings"));
-            dlg.addButton(tr("Cancel"), true, DDialog::ButtonWarning);
-            connect(&dlg, &DDialog::buttonClicked, this, [ = ] (int idx) {
-                if (idx == 0) {
-                    DDBusSender()
-                    .service("com.deepin.defender.hmiscreen")
-                    .interface("com.deepin.defender.hmiscreen")
-                    .path("/com/deepin/defender/hmiscreen")
-                    .method(QString("ShowPage"))
-                    .arg(QString("securitytools"))
-                    .arg(QString("login-safety"))
-                    .call();
-                }
-            });
-            dlg.exec();
-        }
+        needShowSafetyPage = true;
 
         return false;
     } else {
