@@ -37,6 +37,8 @@
 #include <QHBoxLayout>
 #include <QPushButton>
 #include <QSettings>
+#include <QLocalServer>
+#include <QLocalSocket>
 #include <QDebug>
 
 #include <unistd.h>
@@ -56,7 +58,7 @@ ModifyPasswdPage::ModifyPasswdPage(User *user, bool isCurrent, QWidget *parent)
     , m_isCurrent(isCurrent)
     , m_isBindCheckError(false)
     , m_securityLevelItem(new SecurityLevelItem(this))
-
+    , m_localServer(new QLocalServer(this))
 {
     initWidget();
 }
@@ -147,7 +149,7 @@ void ModifyPasswdPage::initWidget()
     });
     connect(m_curUser, &User::passwordResetFinished, this, &ModifyPasswdPage::resetPasswordFinished);
     connect(m_curUser, &User::startResetPasswordReplied, this, &ModifyPasswdPage::onStartResetPasswordReplied);
-
+    connect(m_curUser, &User::startSecurityQuestionsCheckReplied, this, &ModifyPasswdPage::onSecurityQuestionsCheckReplied);
     connect(m_oldPasswordEdit, &DPasswordEdit::textEdited, this, [ & ] {
         if (m_oldPasswordEdit->isAlert())
         {
@@ -178,36 +180,13 @@ void ModifyPasswdPage::initWidget()
             return ;
         }
         PASSWORD_LEVEL_TYPE m_level = PwqualityManager::instance()->GetNewPassWdLevel(m_newPasswordEdit->text());
-        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_newPasswordEdit->lineEdit()->text(),
-                                                                                          m_newPasswordEdit->lineEdit()->text());
 
         if (m_level == PASSWORD_STRENGTH_LEVEL_HIGH) {
             m_securityLevelItem->setLevel(SecurityLevelItem::HighLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->hideAlertMessage();
-            }
         } else if (m_level == PASSWORD_STRENGTH_LEVEL_MIDDLE) {
             m_securityLevelItem->setLevel(SecurityLevelItem::MidLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->showAlertMessage(tr("A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols"));
-            }
         } else if (m_level == PASSWORD_STRENGTH_LEVEL_LOW) {
             m_securityLevelItem->setLevel(SecurityLevelItem::LowLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->showAlertMessage(tr("A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols"), m_newPasswordEdit, 2000);
-            }
         } else {
             m_newPasswordEdit->showAlertMessage(tr("Error occurred when reading the configuration files of password rules!"));
         }
@@ -234,6 +213,29 @@ void ModifyPasswdPage::initWidget()
     DFontSizeManager::instance()->bind(titleLabel, DFontSizeManager::T5);
 
     setFocusPolicy(Qt::StrongFocus);
+
+    m_localServer->setMaxPendingConnections(1);
+    m_localServer->setSocketOptions(QLocalServer::WorldAccessOption);
+    QString serverName = QString("EnableForgotButton");
+    QLocalServer::removeServer(serverName);
+    if (!m_localServer->listen(serverName)) { // 监听特定的连接
+        qWarning() << "listen failed!" << m_localServer->errorString();
+    } else {
+        qDebug() << "listen success!";
+    }
+    connect(m_localServer, &QLocalServer::newConnection, this, &ModifyPasswdPage::onNewConnection);
+
+    m_client = new QLocalSocket(this);
+    m_client->abort();
+    const QString &server = "ResetpasswordRunning";
+    m_client->connectToServer(server);
+    if(!m_client->waitForConnected(1000)) {
+        qDebug() << "connect failed, server: " << "ResetpasswordRunning " << m_client->errorString();
+        m_forgetPasswordBtn->setEnabled(true);
+    } else {
+        m_client->write("reconnect");
+        m_forgetPasswordBtn->setEnabled(false);
+    }
 }
 
 bool ModifyPasswdPage::judgeTextEmpty(DPasswordEdit *edit)
@@ -301,34 +303,7 @@ void ModifyPasswdPage::onPasswordChangeFinished(const int exitCode, const QStrin
         if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise) || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC))
             return;
 
-        // 密码校验失败并且安全中心密码安全等级不为低，弹出跳转到安全中心的对话框，低、中、高等级分别对应的值为1、2、3
-        QDBusInterface interface(QStringLiteral("com.deepin.defender.daemonservice"),
-                                     QStringLiteral("/com/deepin/defender/daemonservice"),
-                                     QStringLiteral("com.deepin.defender.daemonservice"));
-        QDBusReply<int> level = interface.call("GetPwdLimitLevel");
-        if (!interface.isValid()) {
-            return;
-        }
-        if (level != 1) {
-            QDBusReply<QString> errorTips = interface.call("GetPwdError");
-            DDialog dlg("", errorTips, this);
-            dlg.setIcon(QIcon::fromTheme("preferences-system"));
-            dlg.addButton(tr("Go to Settings"));
-            dlg.addButton(tr("Cancel"), true, DDialog::ButtonWarning);
-            connect(&dlg, &DDialog::buttonClicked, this, [ = ](int idx) {
-                if (idx == 0) {
-                    DDBusSender()
-                    .service("com.deepin.defender.hmiscreen")
-                    .interface("com.deepin.defender.hmiscreen")
-                    .path("/com/deepin/defender/hmiscreen")
-                    .method(QString("ShowPage"))
-                    .arg(QString("securitytools"))
-                    .arg(QString("login-safety"))
-                    .call();
-                }
-            });
-            dlg.exec();
-        }
+        Q_EMIT requestCheckPwdLimitLevel();
     } else if (error != PW_NO_ERR) {
         m_newPasswordEdit->setAlert(true);
         m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error));
@@ -353,7 +328,6 @@ void ModifyPasswdPage::resetPassword(const QString &password, const QString &rep
     bool check = false;
     PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_curUser->name(),
                                                                                       password);
-
     if (error != PW_NO_ERR) {
         m_newPasswordEdit->setAlert(true);
         m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error));
@@ -374,8 +348,18 @@ void ModifyPasswdPage::resetPassword(const QString &password, const QString &rep
         }
     }
 
-    if (check)
+    if (check){
+        // 企业版控制中心修改密码屏蔽安全中心登录安全的接口需求
+        if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise)
+            || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC)) {
+            return;
+        }
+
+        if(error != PW_NO_ERR){
+            Q_EMIT requestCheckPwdLimitLevel();
+        }
         return;
+    }
 
     if (!m_passwordTipsEdit->text().simplified().isEmpty())
         requestSetPasswordHint(m_curUser, m_passwordTipsEdit->text());
@@ -414,47 +398,54 @@ void ModifyPasswdPage::resetPasswordFinished(const QString &errorText)
 void ModifyPasswdPage::onForgetPasswordBtnClicked()
 {
     m_forgetPasswordBtn->setEnabled(false);
-
-    QString uosid;
-    Q_EMIT requestUOSID(uosid);
-    if (uosid.isEmpty()) {
-        return;
-    }
-
-    QString uuid;
-    Q_EMIT requestUUID(uuid);
-    if (uuid.isEmpty()) {
-        return;
-    }
-
-    Q_EMIT requestLocalBindCheck(m_curUser, uosid, uuid);
+    Q_EMIT requestSecurityQuestionsCheck(m_curUser);
 }
 
 void ModifyPasswdPage::onStartResetPasswordReplied(const QString &errorText)
 {
     if (!errorText.isEmpty()) {
         m_forgetPasswordBtn->setEnabled(true);
-    } else {
-        m_enableBtnTimer.singleShot(5000, this, [this]{ m_forgetPasswordBtn->setEnabled(true); });
     }
     qDebug() << "Resetpassword reply:" << errorText;
 }
 
+void ModifyPasswdPage::onSecurityQuestionsCheckReplied(const QList<int> &questions)
+{
+    if (!questions.isEmpty()) {
+        Q_EMIT requestStartResetPasswordExec(m_curUser);
+    } else {
+        QString uosid;
+        Q_EMIT requestUOSID(uosid);
+        if (uosid.isEmpty()) {
+            return;
+        }
+
+        QString uuid;
+        Q_EMIT requestUUID(uuid);
+        if (uuid.isEmpty()) {
+            return;
+        }
+        Q_EMIT requestLocalBindCheck(m_curUser, uosid, uuid);
+    }
+    qDebug() << "IsSecurityQuestionsExist:" << !questions.isEmpty();
+}
+
 void ModifyPasswdPage::onLocalBindCheckUbid(const QString &ubid)
 {
     if (!ubid.isEmpty()) {
         m_isBindCheckError = false;
         Q_EMIT requestStartResetPasswordExec(m_curUser);
-    }
-    if (ubid.isEmpty() && !m_isBindCheckError) {
+    } else if (!m_isBindCheckError) {
         UnionIDBindReminderDialog dlg;
         dlg.exec();
+        m_forgetPasswordBtn->setEnabled(true);
     }
 }
 
 void ModifyPasswdPage::onLocalBindCheckError(const QString &error)
 {
     m_isBindCheckError = true;
+    m_forgetPasswordBtn->setEnabled(true);
     QString tips;
     if (error.contains("7500")) {
         tips = tr("System error");
@@ -467,3 +458,16 @@ void ModifyPasswdPage::onLocalBindCheckError(const QString &error)
                                                  tips);
     }
 }
+
+void ModifyPasswdPage::onNewConnection()
+{
+    if (m_localServer->hasPendingConnections()) {
+        QLocalSocket *socket = m_localServer->nextPendingConnection();
+        connect(socket, &QLocalSocket::readyRead, this, [socket, this] {
+            auto content = socket->readAll();
+            if (content == "close") {
+                m_forgetPasswordBtn->setEnabled(true);
+            }
+        });
+    }
+}
