@@ -48,6 +48,8 @@ class QVBoxLayout;
 class QHBoxLayout;
 class QPushButton;
 class QLabel;
+class QLocalServer;
+class QLocalSocket;
 QT_END_NAMESPACE
 
 
@@ -63,6 +65,7 @@ namespace accounts {
 class ModifyPasswdPage : public QWidget
 {
     Q_OBJECT
+
 public:
     explicit ModifyPasswdPage(dcc::accounts::User *user, bool isCurrent = true, QWidget *parent = nullptr);
     ~ModifyPasswdPage();
@@ -80,6 +83,7 @@ private:
     void resetPasswordFinished(const QString &errorText);
     void onForgetPasswordBtnClicked();
     void onStartResetPasswordReplied(const QString &errorText);
+    void onSecurityQuestionsCheckReplied(const QList<int> &questions);
 
 Q_SIGNALS:
     void requestChangePassword(dcc::accounts::User *userInter, const QString &oldPassword, const QString &password, const QString &repeatPassword, const bool needResule = true);
@@ -90,10 +94,13 @@ Q_SIGNALS:
     void requestUUID(QString &uuid);
     void requestLocalBindCheck(dcc::accounts::User *user, const QString &uosid, const QString &uuid);
     void requestStartResetPasswordExec(dcc::accounts::User *user);
+    void requestSecurityQuestionsCheck(dcc::accounts::User *user);
+    void requestCheckPwdLimitLevel();
 
 public Q_SLOTS:
     void onLocalBindCheckUbid(const QString &ubid);
     void onLocalBindCheckError(const QString &error);
+    void onNewConnection();
 
 private:
     dcc::accounts::User *m_curUser;
@@ -106,6 +113,8 @@ private:
     bool m_isBindCheckError;
     dcc::widgets::SecurityLevelItem *m_securityLevelItem;
     QTimer m_enableBtnTimer;
+    QLocalServer *m_localServer;
+    QLocalSocket *m_client;
 };
 }
 }
