@@ -30,6 +30,7 @@
 #include "window/utils.h"
 #include "window/mainwindow.h"
 #include "window/gsettingwatcher.h"
+#include "window/insertplugin.h"
 
 using namespace DCC_NAMESPACE;
 using namespace DCC_NAMESPACE::commoninfo;
@@ -124,8 +125,13 @@ int CommonInfoModule::load(const QString &path)
     if (!m_commonWidget) {
         active();
     }
-
-    return m_commonWidget->showPath(path);
+    const QStringList &page = availPage();
+    int i = page.indexOf(path);
+    if (i != -1) {
+        m_commonWidget->setCurrentIndex(i);
+        return 0;
+    }
+    return -1;
 }
 
 QStringList CommonInfoModule::availPage() const
@@ -136,7 +142,7 @@ QStringList CommonInfoModule::availPage() const
     if (!IsServerSystem && !IsCommunitySystem) {
         sl << "User Experience Program" << "Developer Mode";
     }
-
+    sl.append(InsertPlugin::instance()->availPages(name()));
     return sl;
 }
 
@@ -263,12 +269,14 @@ void CommonInfoModule::initSearchData()
 
     auto func_bootMenu_changed = [ = ] {
         bool visible = false;
-#ifndef DCC_DISABLE_GRUB
         visible = func_is_visible("bootMenu");
-#endif
         m_frameProxy->setWidgetVisible(module, bootMenu, visible);
+#ifndef DCC_DISABLE_GRUB
         m_frameProxy->setDetailVisible(module, bootMenu, startupDelay, visible && func_is_visible("commoninfoBootBootdelay", true));
+#ifndef DCC_DISABLE_GRUB_THEME
         m_frameProxy->setDetailVisible(module, bootMenu, theme, visible && func_is_visible("commoninfoBootTheme", true));
+#endif
+#endif
         m_frameProxy->setDetailVisible(module, bootMenu, auth, visible && (m_commonModel ? m_commonModel->isShowGrubEditAuth() : true));
     };
 
